@@ -1,12 +1,10 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: KVM.pm 556 2012-02-06 20:24:05Z liske $
-#
 # Authors:
 #   Thomas Liske <liske@ibh.de>
 #
 # Copyright Holder:
-#   2009 - 2011 (C) IBH IT-Service GmbH [http://www.ibh.de/]
+#   2009 - 2012 (C) IBH IT-Service GmbH [http://www.ibh.de/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -95,7 +93,7 @@ sub detect($) {
     # Check /proc/cpuinfo
     my %cpuinfo = cpuinfo_get();
     foreach my $cpu (keys %cpuinfo) {
-	if(${$cpuinfo{$cpu}}{'model name'} =~ /QEMU Virtual CPU/) {
+	if(exists(${$cpuinfo{$cpu}}{'model name'}) && ${$cpuinfo{$cpu}}{'model name'} =~ /QEMU Virtual CPU/) {
 	    ImVirt::inc_pts($dref, IMV_PTS_MAJOR, IMV_VIRTUAL, PRODUCT);
 	}
     }
@@ -115,13 +113,6 @@ sub detect($) {
         }
     }
 
-    # Look for a dmesg paravirtualization line
-    if(defined(my $m = dmesg_match(
-	'Booting paravirtualized kernel on KVM' => IMV_PTS_MAJOR,
-     ))) {
-	ImVirt::inc_pts($dref, $m, IMV_VIRTUAL, PRODUCT) if($m > 0);
-    }
-
     # Look for virtio modules
     my $p = kmods_match_used(
 	'^virtio(_(blk|pci|net|ballon|ring))?$' => IMV_PTS_MINOR,
