@@ -1,12 +1,10 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: OpenVZ.pm 521 2010-07-02 12:35:15Z liske $
-#
 # Authors:
 #   Thomas Liske <liske@ibh.de>
 #
 # Copyright Holder:
-#   2009 - 2010 (C) IBH IT-Service GmbH [http://www.ibh.de/]
+#   2009 - 2012 (C) IBH IT-Service GmbH [http://www.ibh.de/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -40,6 +38,15 @@ sub detect($) {
 
     my $dref = shift;
 
+    foreach my $fn (qw(time_list bus/pci/devices bus/input/devices)) {
+	if(procfs_isfile('time_list')) {
+	    ImVirt::dec_pts($dref, IMV_PTS_MINOR, IMV_VIRTUAL, PRODUCT);
+	}
+	else {
+	    ImVirt::inc_pts($dref, IMV_PTS_MINOR, IMV_VIRTUAL, PRODUCT);
+	}
+    }
+
     if(procfs_isdir('vz') && !procfs_isdir('bc')) {
 	ImVirt::inc_pts($dref, IMV_PTS_MAJOR, IMV_VIRTUAL, PRODUCT);
     }
